@@ -26,13 +26,13 @@ upsdrv_info_t comm_upsdrv_info = {
 #define MAX_TRY_OPENUSB 32
 
 /* Powerware */
-#define POWERWARE 0x0592
+#define POWERWARE_VENDORID	0x0592
 
 /* Phoenixtec Power Co., Ltd */
-#define PHOENIXTEC 0x06da
+#define PHOENIXTEC_VENDORID	0x06da
 
 /* Hewlett Packard */
-#define HP_VENDORID 0x03f0
+#define HP_VENDORID	0x03f0
 
 static USBDevice_t curDevice;
 
@@ -81,10 +81,10 @@ static void *phoenixtec_ups(USBDevice_t *device) {
 /* USB IDs device table */
 static usb_device_id_t pw_usb_device_table[] = {
 	/* various models */
-	{ USB_DEVICE(POWERWARE, 0x0002), &powerware_ups },
+	{ USB_DEVICE(POWERWARE_VENDORID, 0x0002), &powerware_ups },
 
 	/* various models */
-	{ USB_DEVICE(PHOENIXTEC, 0x0002), &phoenixtec_ups },
+	{ USB_DEVICE(PHOENIXTEC_VENDORID, 0x0002), &phoenixtec_ups },
 
 	/* T500 */
 	{ USB_DEVICE(HP_VENDORID, 0x1f01), &phoenixtec_ups },
@@ -231,7 +231,7 @@ ssize_t get_answer(unsigned char *data, unsigned char command)
 		/* Now validate XCP frame */
 		/* Check header */
 		if ( my_buf[0] != PW_COMMAND_START_BYTE ) {
-			upsdebugx(2, "get_answer: wrong header 0xab vs %02x", my_buf[0]);
+			upsdebugx(2, "get_answer: wrong header 0xab vs. %02x", my_buf[0]);
 			/* Sometime we read something wrong. bad cables? bad ports? */
 			my_buf = memchr(my_buf, PW_COMMAND_START_BYTE, bytes_read);
 			if (!my_buf)
@@ -266,11 +266,11 @@ ssize_t get_answer(unsigned char *data, unsigned char command)
 		/* Test the Sequence # */
 		sequence = my_buf[3];
 		if ((sequence & PW_SEQ_MASK) != seq_num) {
-			nutusb_comm_fail("get_answer: not the right sequence received %x!!!\n", (sequence & PW_SEQ_MASK));
+			nutusb_comm_fail("get_answer: not the right sequence received %x!!!\n", (unsigned int)(sequence & PW_SEQ_MASK));
 			return -1;
 		}
 		else {
-			upsdebugx(2, "get_answer: sequence number (%x) is ok", (sequence & PW_SEQ_MASK));
+			upsdebugx(2, "get_answer: sequence number (%x) is ok", (unsigned int)(sequence & PW_SEQ_MASK));
 		}
 
 		/* Validate checksum */
@@ -538,7 +538,7 @@ usb_dev_handle *nutusb_open(const char *port)
 				upsdebugx(1, "Can't set POWERWARE USB configuration: %s", nut_usb_strerror(ret));
 				errout = 1;
 			}
-#endif
+#endif	/* WIN32 */
 			if ((ret = usb_claim_interface(dev_h, 0)) < 0)
 			{
 				upsdebugx(1, "Can't claim POWERWARE USB interface: %s", nut_usb_strerror(ret));
