@@ -41,7 +41,7 @@
 #include "safenet.h"
 
 #define DRIVER_NAME	"Generic SafeNet UPS driver"
-#define DRIVER_VERSION	"1.83"
+#define DRIVER_VERSION	"1.84"
 
 /* driver description structure */
 upsdrv_info_t upsdrv_info = {
@@ -473,6 +473,11 @@ void upsdrv_help(void)
 {
 }
 
+/* optionally tweak prognames[] entries */
+void upsdrv_tweak_prognames(void)
+{
+}
+
 void upsdrv_makevartable(void)
 {
 	addvar(VAR_VALUE, "manufacturer", "manufacturer [unknown]");
